betty.plugin.static module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.plugin.static module

Provide static plugin management.

final class betty.plugin.static.StaticPluginRepository

  Bases: `PluginRepository`[`_PluginT`], `Generic`[`_PluginT`]

  A repository that is given a static collection of plugins, and exposes those.

  __init__(*plugins: type[_PluginT])
  async get(plugin_id: str) → type[_PluginT]

    Get a single plugin by its ID.

    Raises:

      PluginNotFound – if no plugin can be found for the given ID.